容器存储数据到这个文件夹，在 `docker-compose.yaml` 用相对路径（`./volumes/`）映射到容器里。这样本地测试会很方便。
sync 同步时会忽略这个文件夹。若想做服务的初始数据，请放到`release`，并在服务启动时导入。
创建项目时，会自动添加到 `.gitignore`，这个文件夹理应不存在需要版本控制的数据。
**容器内数据放在这，servers、releace 同步时会被删除。**